@@ -32,7 +32,7 @@ function parseVersionString(string) {
 /**
  * Returns true if the current shell version is greater than the version string passed.
  *
- * @param {string} version
+ * @param {string} string Version string like 3.38.
  */
 function versionGreaterOrEqual(string) {
     let current = parseVersionString(imports.misc.config.PACKAGE_VERSION);
@@ -46,15 +46,3 @@ function versionGreaterOrEqual(string) {
 
     return true;
 }
-
-
-/**
- * Helper to repeat a given string.
- *
- * @param {string} string
- * @param {number} times
- * @returns {string}
- */
-function repeat(string, times) {
-    return new Array(times + 1).join(string);
-}
